**To disassociate the certificate from the wireless gateway**

The following ``disassociate-wireless-gateway-from-certificate`` disassociates a wireless gateway from its currently associated certificate. ::

    aws iotwireless disassociate-wireless-gateway-from-certificate \
        --id "12345678-a1b2-3c45-67d8-e90fa1b2c34d" 

This command produces no output.

For more information, see `Add your gateways and wireless devices to AWS IoT Core for LoRaWAN <https://docs.aws.amazon.com/iot/latest/developerguide/connect-iot-lorawan-onboard-devices.html>`__ in the *AWS IoT Developers Guide*.
